4.8.0 (2024-05-21)
==================

🎉 New features
---------------

- serverctl: add an option to restore the most recent backup
- serverctl: add region, secure and cert_check options to s3 db dump/restore
